# Copyright 2022 The Feathub Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from typing import Dict

from feathub.feature_tables.feature_table import FeatureTable


class OnlineStoreSink(FeatureTable):
    """
    A sink corresponding to a table in an online feature store.
    """

    def __init__(self, store_type: str, table_name: str):
        """
        :param store_type: A string that uniquely identifies a store class.
        :param table_name: The name of a table in the feature store.
        """
        super().__init__(
            name="",
            system_name=store_type,
            properties={"table_name": table_name},
        )
        self.store_type = store_type
        self.table_name = table_name

    def to_json(self) -> Dict:
        return {
            "type": "OnlineStoreSink",
            "store_type": self.store_type,
            "table_name": self.table_name,
        }
